# Pigreads

![Graphical abstract illustrating some of the key features of Pigreads.](fig/abstract.png)

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

## Showcase

![Pigreads can be used to solve reaction-diffusion systems in up to three dimensions.](fig/teaser.png)

**Pigreads can be used to solve reaction-diffusion systems in up to three
dimensions.** **A.** Cardiac action potentials for the model by
[Courtemanche, Ramirez, and Nattel (1998)](models/courtemanche1998ionic) in the
0D case, i.e., without diffusion. **B.** Three travelling pulses in a cable (1D)
followed by a fourth blocked pulse in the same model. **C.** A spiral wave in a
circular 2D domain in the model by
[Marcotte and Grigoriev (2017)](models/marcotte2017dynamical) that was
stimulated by increasing the main variable on a line between high and low values
of the recovery variable. **D.** Pseudo-electrograms for a travelling wave in a
2D piece of tissue with periodic boundary conditions on the top and bottom and
different cell types for mid-wall, endo-, and epi-cardial cells following the
model by [ten Tusscher and Panfilov (2006)](models/tentusscher2006alternans)
with 15% fibrosis, stimulated three pulses at the locations and times labelled
S0–2. **E.** Three-dimensional cardiac electrophysiology simulations in human
bi-ventricular (Hren 1996,
[Kelderman et al. 2009](https://doi.org/10.1152/ajpheart.00952.2008),
[Hren 1998](https://doi.org/10.1088/0031-9155/43/6/006)) and human bi-atrial
([De Coster et al. 2018](https://doi.org/10.3389/fphys.2018.01381),
[Dössel et al. 2011](https://doi.org/10.1109/iembs.2011.6091073)) geometries
with faster diffusion along muscle fibres. A single pulse is sent out from the
apex or the sino-atrial node, respectively. We use the models by
[ten Tusscher and Panfilov (2006)](models/tentusscher2006alternans) for the
ventricles and by
[Courtemanche, Ramirez, and Nattel (1998)](models/courtemanche1998ionic) for the
atria.

Scripts to generate the figures presented in this documentation are available in
a [separate Git repository](https://gitlab.com/pigreads/figures).

## Contents

```{toctree}
:maxdepth: 1

math
tech
example
api/index
cli
models/index
schema/index
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
